GamepadButtonInputEvent class

Gamepad button press/release event

Inheritance

Constructors

GamepadButtonInputEvent({required GamepadButtonId button, required bool isDown})
const
GamepadButtonInputEvent.down(GamepadButtonId button)
factory
GamepadButtonInputEvent.up(GamepadButtonId button)
factory

Properties

button GamepadButtonId
final
hashCode int
The hash code for this object.
no setterinherited
isDown bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited