MouseWheelInputEvent class

Mouse wheel scroll event

Inheritance

Constructors

MouseWheelInputEvent({required MouseWheelDirection direction, required int delta})
const
MouseWheelInputEvent.down([int delta = 3])
Create a scroll down event
factory
MouseWheelInputEvent.up([int delta = 3])
Create a scroll up event
factory

Properties

delta int
final
direction MouseWheelDirection
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited