JoystickInputEvent class
Joystick state change event
- Inheritance
-
- Object
- InputEvent
- JoystickInputEvent
Constructors
-
JoystickInputEvent({required double dx, required double dy, required List<
KeyboardKey> activeKeys}) -
const
Properties
-
activeKeys
→ List<
KeyboardKey> -
final
- dx → double
-
final
- dy → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited