VirtualMouseButton class
Virtual Mouse Button Control.
Simulates mouse clicks (left, right, middle).
- Inheritance
-
- Object
- VirtualControl
- VirtualMouseButton
Constructors
-
VirtualMouseButton({required String id, required String label, required ControlLayout layout, required TriggerType trigger, Map<
String, dynamic> config = const {}, ControlStyle? style, ControlFeedback? feedback, required MouseButtonId button, String clickType = 'single'}) - Creates a virtual mouse button.
-
VirtualMouseButton.fromJson(Map<
String, dynamic> json) -
Creates a VirtualMouseButton from a JSON map.
factory
-
VirtualMouseButton.leftAsDefaultButton({required String id, required ControlLayout layout, ControlStyle? style, ControlFeedback? feedback, Map<
String, dynamic> config = const {'uiStyle' : 'button'}, String label = 'L', TriggerType trigger = TriggerType.tap}) -
VirtualMouseButton.rightAsDefaultButton({required String id, required ControlLayout layout, ControlStyle? style, ControlFeedback? feedback, Map<
String, dynamic> config = const {'uiStyle' : 'button'}, String label = 'R', TriggerType trigger = TriggerType.hold})
Properties
-
actions
→ List<
ControlAction> -
List of actions associated with the control.
finalinherited
-
The mouse button (left, right, middle).
final
- clickType → String
-
The click type (single, double, hold).
final
-
config
→ Map<
String, dynamic> -
Additional configuration parameters.
finalinherited
- feedback → ControlFeedback?
-
Haptic feedback configuration.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for the control.
finalinherited
- label → String
-
Display label for the control.
finalinherited
- layout → ControlLayout
-
Layout configuration (position and size).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ControlStyle?
-
Visual style configuration.
finalinherited
- trigger → TriggerType
-
Interaction trigger type.
finalinherited
- type → String
-
The type of control (e.g., 'button', 'joystick').
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the control to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited